# ParsTalk

📢 ParsTalk یک کتابخانه پایتونی برای **تبدیل متن فارسی به فینگلیش** با تشخیص مصوت‌هاست که متن را همچنین به صورت صوتی نیز پخش می‌کند.

---

## ✨ ویژگی‌ها

- درک مصوت‌ها
- پشتیبانی از تبدیل به صدا با استفاده از `pyttsx3`
- نصب آسان و استفاده راحت فقط با یک تابع

---

## 🛠️ نحوه استفاده

```python
from parstalk import farsi_to_finglish_with_vowels_and_speech

farsi_text = "داوود"
finglish = farsi_to_finglish_with_vowels_and_speech(farsi_text)
print(finglish)
نصب ساده با استفاده از:
pip install parstalk

👤 نویسنده
محمدجواد قادری
📧 Mohammadjavadd.ronaldo@gmail.com
